#!/bin/bash
# packager         : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location  : http://fuse.sourceforge.net/sshfs.html
# last revised     : 20.12.2007

softname='sshfs'
softversion='1.9'
packageversion='50.1'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-fuse-$softversion.tar.gz"
src="$buildir/$softname-fuse-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# put slack-desc in place.
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
sshfs: Filesystem client based on the SSH File Transfer Protocol.
sshfs:
sshfs: Since most SSH servers already support this protocol it is very
sshfs: easy to set up: i.e. on the server side there's nothing to do.
sshfs: On the client side mounting the filesystem is as easy as
sshfs: logging into the server with ssh.
sshfs:
sshfs:
sshfs: Homepage: http://fuse.sourceforge.net/sshfs.html
sshfs:
sshfs: 
EOF

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
        --prefix=$prefix \
        --program-prefix="" \
        --program-suffix="" \
    
    make
    make install DESTDIR=$dest
    
# add default docs
cp -a \
      AUTHORS INSTALL README COPYING ChangeLog FAQ.txt NEWS \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
